function AvgRes(ha, AvgLength,AvgTime)
% Function to plot averaged Residuals.  Plotting is done by replacing the X
% and Y data on the plots themselves.
% MOD TAH 090312: Added boundary time AvgTime (zero if not set)
%

% Find the residuals associated with this set of axes
axes(ha);
%he = findobj(ha,'Tag','PlotErrb'); 
hr = findobj(ha,'Tag','PlotRes');
%
% Remove error bars from plot
% delete(he);
%
% Now get the data
rall = get(hr(1),'UserData');
times = rall{1}; res = rall{2}; err = rall{3};
delete(hr);
%
% Now average the data
start = min(times); stop = max(times);
%
dyr = AvgLength/365.25;

% MOD TAH 090312: See if need to adjust for AvgTime (boundary should fall
% on requested day).
if AvgTime ~= 0
    starto = start;
    start = floor((start-AvgTime)/dyr)*dyr + AvgTime;
    fprintf('Average start: Data %f , boundary %f Step %f yr\n',starto,start,dyr);
    
end
    
%
avT = []; avR = []; avS = [];
for t = start:dyr:stop
    sel = find(times >= t & times < t+dyr);
    ats = times(sel); ars = res(sel); ass = err(sel);
    % Now find the weighted means
    num = length(ats);
    if( num > 1 )
        w = 1./ass.^2;
        Wmean = w*ars'/sum(w); r = ars - Wmean;
        nrms = sqrt(sum(r.^2.*w)/(num-1)); 
        werr = sqrt(1/sum(w));
        Tmean = w*ats'/sum(w);
        avT = [avT Tmean]; avR = [avR Wmean]; avS = [avS werr];
    end
end
%
% OK plot the averaged values
he = errorbar(avT,avR,avS,'ks-') ;
set(he,'MarkerSize',9,'MarkerFaceColor',[1 0 0],'LineWidth',2);
% Save the data so that we can average later if requested
set(he,'Tag','PlotRes'); % set(he(1),'Tag','PlotErrb');
set(he,'UserData',{times,res,err});
ymn = min(avR); ymx = max(avR); dy = ymx-ymn;
set(ha,'Ylim',[ymn-0.2*dy ymx+0.2*dy]);
%
% Now compute the WRMS and NRMS
num = length(avT);
if( num > 0 )
    w = 1./avS.^2;
    nrms = sqrt(sum(avR.^2.*w)/(num-1)); 
    wrms = nrms*sqrt(num/sum(w));
    txt = sprintf('Av %6.1f days, # %d, WRMS %6.2f mm NRMS %6.1f', ...
        AvgLength, num, wrms, nrms);
    % See if Average text already present.  If it is delete it
    ht = findobj(ha,'Tag','AvgText');
    if ~isempty(ht) 
        delete(ht);
    end
    ht = text(0.01,1.050,txt, ...
        'VerticalAlignment','bottom','Units','normalized','FontWeight','bold', ...
        'Tag','AvgText');  
end

        
    

