function [hp,Data,edits] = gpsplot(ha,DataI,res,edits,symI,sigmacut,outliercut,absmean,lb)
% GPSPLOT: Plot and edting module
%
% MOD TAH 060126: Added absmean which gives the size of the mean value that
% should not be removed before plotting
% MOD TAH 141211: Add passinf lb as Label Number (1) North, (2) East (3) Up
% Activate current axes
%symbols = ['bs';'b^';'bv';'bd';'bo'];
symbols = ['o';'s';'^';'o';'s'];
mcolor = [0 0 1 ; 0.3 0.3 0.3 ; 0.94 0.60 0.16 ; 0.41 0.63 0.12 ; 0.63 0.95 0.95 ];
msize = [4 4 5 4 4];
labs = ['North (mm)'; 'East  (mm)'; ' Up  (mm) ']; 

axes(ha); cla;

% Apply the edits passed into routine
eds = ones(1,length(DataI(1,:)));
eds = logical(eds);
for k = 1:length(edits)
    eds(edits(k)) = 0;
end
          
Data = DataI(:,eds); sym = symI(:,eds);

% Do the editing on sigma on load
GoodSig = find(Data(3,:)<sigmacut);
Data = [Data(1,GoodSig); Data(2,GoodSig); Data(3,GoodSig)];
sym = sym(GoodSig);

% If the residuals are passed plot these, otherwise the data themselves
if length(res) > 0
    ydat = res(eds);
else
    ydat = Data(2,:);
end

% MOD TAH 060126: See if mean should be removed
ymean = mean(ydat);
if abs(ymean) < absmean, ymean = 0; end

% Get Matlab version to see which path
%aver = ver('MATLAB') ; mver = str2num(aver.Version(1:3));
mver = 6.1;

% Remove the mean and plot
% Clean off exiting plot:
delete(get(ha,'Children'));
ylmx = max(ydat-ymean)+0.5e-3; ylmn = min(ydat-ymean)-0.5e-3;
ylim = [ylmn-(ylmx-ylmn)*0.05 ylmx+(ylmx-ylmn)*0.05];
xmin = min(Data(1,:)); xmax = max(Data(1,:)); dx = xmax - xmin;
xlim = [xmin-dx*0.01-0.001 xmax+dx*0.01+0.001];
%hp = plot(Data(1,:),ydat-mean(ydat),'bs','MarkerSize',4); % Save the graphics handle
he = errorbar(Data(1,:),ydat-ymean,Data(3,:),'.','Color',[0.75 0.75 0.75]) ; 
% Save the data so that we can average later if requested
if mver < 7 
   set(he,'Tag','PlotRes'); % set(he(1),'Tag','PlotErrb');
   set(he,'UserData',{Data(1,:),ydat-ymean,Data(3,:)});
else
   set(he(1),'Tag','PlotRes'); % set(he(1),'Tag','PlotErrb');
   set(he(1),'UserData',{Data(1,:),ydat-ymean,Data(3,:)});
end
set(ha,'Ylim',ylim); set(ha,'Xlim',xlim);
% For each symbol type plot the data
for i = 1:5
    sel = find(sym==i);
    pdx = Data(1,sel);
    if ~isempty(pdx)
        pdy = ydat(sel)-ymean;
        hp = plot(pdx,pdy,symbols(i,:),'MarkerSize',msize(i));
        %set(hp,'MarkerFaceColor',[1 1 0]);
        set(hp,'MarkerFaceColor',mcolor(i,:),'MarkerEdgeColor',mcolor(i,:));
    end
end
% Make an inviible plot will all the data so editing will work.
hp = plot(Data(1,:),ydat-ymean,'g.','Visible','off');

%lims = axis
if ~isempty(lb) 
    ylabel(labs(lb,:)); 
else
    ylabel('Position (mm)');
end
if isempty(res) 
    % Write a put the number of measurements on the plot
    numin = length(DataI(1,:));
    numout = length(Data(1,:));
    rms = std(ydat-ymean);
    numtxt = sprintf('Number in %6d, After sigma limit cut %6d, RMS %6.2f mm',numin,numout,rms);
%   WriteText(lims(1),lims(4),numtxt,[.7 .9 .5]);
    text(0.01,1.005,numtxt, ...
        'VerticalAlignment','bottom','Units','normalized')   % , ...
%       'BackgroundColor',[.7 .9 .5]);   % Add with version 6.5
end

%drawnow
