function [profxy,profvel_sort, profname_sort, profaz] = CompProf(profll,profvel, profname);
% profxy = CompProf(profll,profvel, profname): Computes profile and outputs
%
% First compute the azimith of the profile.  We do this calculation with
% spherical trig to avoid curvature errors.
dtr = pi/180;
cosb = sin(profll(2,2)*dtr)*sin(profll(1,2)*dtr) + ...
    cos(profll(2,2)*dtr)*cos(profll(1,2)*dtr)*cos((profll(2,1)-profll(1,1))*dtr);
plr = acos(cosb); plkm = plr*6371.;
% Now compute the azimith of the profile
sa = cos(profll(2,2)*dtr)*sin((profll(2,1)-profll(1,1))*dtr)/sin(plr);
ca = (sin(profll(2,2)*dtr)-cos(plr)*sin(profll(1,2)*dtr))/ ...
    (sin(plr)*cos(profll(2,2)*dtr));
plaz = atan2(sa,ca);
% See of the azimuth for mapping the vectors onto has been given by the 
% user (ProfAzIn tag)
haz = findobj(gcf,'Tag','ProfAzIn');
azstr = get(haz,'String'); 
if ~isempty(azstr) 
    azdeg = str2num(azstr); profaz = azdeg*dtr;
else
    profaz = plaz;
end
%
% Compute the width of the profile
i = 3 ; % The third (and fourth) entries should be close to the reference point
cosw = sin(profll(i,2)*dtr)*sin(profll(1,2)*dtr) + ...
       cos(profll(i,2)*dtr)*cos(profll(1,2)*dtr)*cos((profll(i,1)-profll(1,1))*dtr);
wdr = acos(cosw); wdkm = wdr*6371.;
%
fprintf(1,'Profile: From %6.3f %6.3f to %6.3f %6.3f\n', ...
    profll(1,[1 2]), profll(2,[1 2]));
fprintf(1,'Length %8.2f km, Azimuth %6.2f deg; Width %6.2f km.\n', plkm, plaz/dtr, wdkm);
fprintf(1,'Velocities projected along azimith %6.2f deg\n',profaz/dtr);
%
% For each point in the profile area compute its along profile, cross
% profile distance and project the velocity into the profile.
% Rotation matrix for EN to AC (along/cross) [Conventon here is from use of
% EN which 90deg away form the usual direction.
R = [sin(profaz) cos(profaz); -cos(profaz) sin(profaz)];
profxy = [];
for i = 1:length(profvel(1,:))
    % Compute distance along prof and normal to prof (left positive)
    % Compute the distance and azimuth from the first point
    cosg = sin(profvel(2,i)*dtr)*sin(profll(1,2)*dtr) + ...
       cos(profvel(2,i)*dtr)*cos(profll(1,2)*dtr)*cos((profvel(1,i)-profll(1,1))*dtr);
    gr = acos(cosg); gkm = gr*6371.;
    sg = cos(profvel(2,i)*dtr)*sin((profvel(1,i)-profll(1,1))*dtr)/sin(gr);
    cg = (sin(profvel(2,i)*dtr)-cos(gr)*sin(profll(1,2)*dtr))/ ...
        (sin(gr)*cos(profvel(2,i)*dtr));
    gaz = atan2(sg,cg);
    % Azimith off profiles
    daz = plaz - gaz; % This is positive to the left of profile
    ofr = asin(sin(gr)*sin(daz)); ofkm = ofr*6371;
    alr = acos(cos(gr)/cos(ofr)); alkm = alr*6371;
    %
    % Now mapping the velocities into the profile directoions
    Vac = R*[profvel(3,i);profvel(4,i)];
    % MAcke covariance matrix
    Cne = [profvel(7,i)^2 profvel(9,i)*profvel(7,i)*profvel(8,i); ...
           profvel(9,i)*profvel(7,i)*profvel(8,i) profvel(8,i)^2];
    Cac = R*Cne*R';
    % Now save the profile array
    profxy = [profxy ; ...
            alkm Vac(1) sqrt(Cac(1,1)) Vac(2) sqrt(Cac(1,1)) profvel(10,i) profvel(12,i) ofkm];
end
% Now sort the entries by distance along profile.
[x, ind] = sort(profxy(:,1));
profxy = profxy(ind,:); profname_sort = profname(ind,:); profvel_sort=profvel(:,ind);

fprintf(1,' Dst km          Along          Cross              Height      OffProf (km)   long     lat  Name\n');
for i = 1: length(profxy(:,1))
    fprintf(1,'%8.2f %7.2f +- %7.2f %7.2f +- %7.2f %7.2f +- %7.2f %8.2f %8.4f %8.4f %s\n',...
        profxy(i,:),profvel_sort([1 2],i), profname_sort(i,:)) ;
end
    
            
    



