function neu_part = GenPart( xyz, rot_mat, np, er, et)
% Generate partials from estimation of translation and rotatiom.

%       xyz_part(1,1) = 1.d0
%       xyz_part(2,2) = 1.d0
%       xyz_part(3,3) = 1.d0
% 
% *     Rotation partials
%       xyz_part(2,4) = -coord(3)
%       xyz_part(3,4) =  coord(2)
%       xyz_part(1,5) =  coord(3)
%       xyz_part(3,5) = -coord(1)
%       xyz_part(1,6) = -coord(2)
%       xyz_part(2,6) =  coord(1)
%  
% *     See if new scale partials
%       if( num_parn.eq.7 ) then
%           xyz_part(1,7) = coord(1)
%           xyz_part(2,7) = coord(2)
%           xyz_part(3,7) = coord(3)
%       else
%           xyz_part(1,7) = 0.d0
%           xyz_part(2,7) = 0.d0
%           xyz_part(3,7) = 0.d0
%       end if
%  
% ***** Now apply the rotation matrix to get NEU partials
%       do i = 1,3
%           do j = 1, num_parn
%               neu_part(i,j) = 0.d0
%               do k = 1,3
%                   neu_part(i,j) = neu_part(i,j) +
%      .                    rot_matrix(i,k)*xyz_part(k,j)
%               end do
%           end do
%           do j = num_parn+1,7
%              neu_part(i,j) = 0.d0
%           end do
%       end do
%  
xyz_part = zeros(3,np) ; % XYZ with respect to parameters
off = 0 ;                % Parameter number offset to get rotations.
if et == 1
    xyz_part(1,1) = 1.0 ; xyz_part(2,2) = 1.0 ; xyz_part(3,3) = 1.0;
    off = 3;
end
if et == 0 && np == 6
    % No Cartesian translation so allow NEU translation.  Add partials at
    % the end
    off = 3 ;  % Set offset so that rotation goes in correct location
end
if er == 1
    xyz_part(2,off+1) = -xyz(3)*1e-6;
    xyz_part(3,off+1) =  xyz(2)*1e-6;
    xyz_part(1,off+2) =  xyz(3)*1e-6;
    xyz_part(3,off+2) = -xyz(1)*1e-6;
    xyz_part(1,off+3) = -xyz(2)*1e-6;
    xyz_part(2,off+3) =  xyz(1)*1e-6;
end

% Now rotate the XYZ partials to NEU
neu_part = rot_mat*xyz_part;
if (et == 0 && np == 6) || ( et==0 && er == 0 )
    % No Cartesian translation so allow NEU translation. Replace first 3x3
    neu_part(1:3,1:3) = eye(3);
end
end
   
    
    
    