function [offs, aligns] = GetOffset(hf)
% offs = GetOffset: returns the values of the offset stored in the OffValue
% handle.  Values are:
% dNEU wxyz type
% dXYZ wxyz type
% where wxyz are the rotation rates about XYZ in rad/Byr.  dNEU and dXYZ
% are mm/yr units.
% Type sets types: 0 == No values 1 == dNEU ; 2 == dXYZ


% Find the handle
hov = findobj(hf,'Tag','Offvalue');
offstr = get(hov,'String');
% If the string is not empty, read the values
dNEU = zeros(3,1); wxyz = zeros(3,1);
if ~isempty(offstr)
    [dNEU, cnt, msg, nexti] = sscanf(offstr,'%f',3);
    if cnt == 2 , dNEU(3) = 0 ; end
    [type, cnt, msg, nextj] = sscanf(offstr(nexti:end),'%s',1);
    [wxyz, cnt]              = sscanf(offstr(nexti+nextj:end),'%f',3);
    if isempty(wxyz) , wxyz = zeros(3,1); end
    
    if strcmp(type,'XYZ')
        offs = [dNEU' wxyz' 2];
    else
        offs = [dNEU' wxyz' 1];
    end
else
    offs = zeros(1,7); 
end
% Final check to make sure values are not zero.
if offs(1:6)*offs(1:6)' == 0, offs(7) = 0 ; end

% Get the alignment values
hov = findobj(hf,'Tag','Alignvalue');
Alignstr = get(hov,'String');

dNEU = zeros(3,1); wxyz = zeros(3,1);
if ~isempty(Alignstr)
    [dNEU, cnt, msg, nexti] = sscanf(Alignstr,'%f',3);
    if cnt == 2 , dNEU(3) = 0 ; end
    [type, cnt, msg, nextj] = sscanf(Alignstr(nexti:end),'%s',1);
    [wxyz, cnt]              = sscanf(Alignstr(nexti+nextj:end),'%f',3);
    if isempty(wxyz) , wxyz = zeros(3,1); end
    
    if strcmp(type,'XYZ')
        aligns = [dNEU' wxyz' 2];
    else
        aligns = [dNEU' wxyz' 1];
    end
else
    aligns = zeros(1,7); 
end
% Final check to make sure values are not zero.
if aligns(1:6)*aligns(1:6)' == 0 , aligns(7) = 0 ; end
end

