function handles = Hplot(ha, names, vels, llsize, velinf, arrowstr)
% VPLOT: Plots vectors with UIcontextMenu Items
% fld is 1 for primary, 2 for secondary field, 3 for ensum field
% handles is a cell array that contains the handles to quanties ploted.
% ha is axis handle

% Number of vectors
handles = [];
if isempty(vels), return; end
num = length(vels(1,:));
axsize = get(ha,'Position');

% Get which series we are plotting
field = velinf.Field;
if strcmp(field,'VelName1' ) 
    fld = 1; 
elseif strcmp(field,'VelName2' ) 
    fld = 2;
else
    fld =3; 
end

% Now get the scaling the velocity vectors
ah = velinf.ArrowH;
av = velinf.ArrowV;
ppmm = 3.5;  % Pixels-per-mm to use
maxvel = max([abs(vels(3,:)) abs(vels(4,:))]);
% Check to max sure that we can plot at all with the scaling. If we loading
% the file
cbtag = get(gcbo,'Tag');
ldin = strfind(cbtag,'LoadVel1');

if ah*maxvel*ppmm*4 > min(axsize(3:4)) && ~isempty(ldin)
    % We can't possibly plot as requested by user.  Reset the scaling
    % so that we have a chance.
    ahn = min(axsize(3:4))/(4*maxvel*ppmm);
    mess = sprintf('Arrow length value too large, Resetting %6.2f to %6.2f',ah,ahn);
    ah = ahn; velinf.ArrowH = ah;
    has = findobj(gcf,'Tag','ArrowH');
    hf = gcf ;
    ahstr = sprintf('%6.3f',ah); set(has,'String',ahstr);
    % Print message to screen
    errordlg(mess); pause(3);
    figure(hf) ;  % Move focus back to velview figure
end

% If only velocities passed, auto compute the scales
if isempty(llsize)
    lnglims = [min(vels(1,:)) max(vels(1,:))];
    latlims = [min(vels(2,:)) max(vels(2,:))];
    % Based on vector lengths and how they will scale, refine the lat/long
    % lims need.  Since we are aiming at m mm-on-screen ~ 1 mm real, we
    % need to repeat several times.  We only do this for horizontal. 
    % (2.835 pixels/mm at 72 pixels/inch).  Actual screens seem a bit
    % smaller than this plus we will add 10% margin, so use 3.5 instead.
    sp = [0 0]; 
    [sn,cml] = VelScale(ha,[lnglims latlims]);
    cnt = 0;
    while (sn-sp)*(sn-sp)'/(sn*sn') > 0.0001 && cnt < 10
        cnt = cnt + 1; 
        % Get the highest and lowest points using current scales (positions
        % with velocity vectors and positions themselves)
        sp = sn;
        latmax = max([vels(2,:)+vels(4,:)*sn(2)*ah vels(2,:)]);
        latmin = min([vels(2,:)+vels(4,:)*sn(2)*ah vels(2,:)]); dlat = latmax-latmin;
        lngmax = max([vels(1,:)+vels(3,:)*sn(1)*ah vels(1,:)]);
        lngmin = min([vels(1,:)+vels(3,:)*sn(1)*ah vels(1,:)]); dlng = lngmax-lngmin;
        %cml = cos((latmax+latmin)*pi/360);  % Take mean
        % Based on these ranges, see which direction will set the scale
        % (i.e, will lat or long cover the full axis scale).  After some
        % algebra, the condition to see if lat sets the scales is:
        [sn,cml] = VelScale(ha,[lngmin lngmax latmin latmax]);
        %if axsize(3)/axsize(4)*dlat/(dlng*cml) > 1
        %    sn = dlat*1.1/axsize(4)*ppmm;
        %else
        %    sn = dlng*1.1*cml/axsize(4)*ppmm;
        %end
    end
    % Save the final scales needed
    llsize = [lngmin-dlng*0.02 lngmax+dlng*0.02 latmin-dlat*0.02 latmax+dlat*0.02];
end
% Using scales passed by user compute the vector scaling
[sn,cml] = VelScale(ha,llsize);

scaleH = sn*ah;   % Scale times arrow size should map vectors to requested size
scaleV = sn*av;
% Now generate each of the vectors
% Find the label for vel
confidH = velinf.ConfidH;
conradH = sqrt(-2.0*log(1-confidH/100));
%confidV = velinf.ConfidV;
%conradV = sqrt(2)*erfinv(confidV/100);
set(gca,'NextPlot','add');
set(ha,'DataAspectRatio',[1 cml 1]);
axis(llsize);   % Set the axes size we need.
hhp=[]; hhe=[]; hha=[]; hvp=[]; hve=[]; ht=[];
if velinf.DisplayH
    for i = 1:num
        [lx,ly] = VelToPlot(vels(:,i), scaleH, arrowstr, velinf);  % Returns 5 element vector with arrow
        if ~isempty(names)
            cb = sprintf('velgui(''HVector'',''%8s'',%3d,%1d)',names(i,:), i,fld);
        else
            cb = []; 
        end
        % Plot the error ellipose first
        errpos = [lx(2)-vels(7,i)*scaleH(1)*conradH ...
                  ly(2)-vels(8,i)*scaleH(2)*conradH ...
                vels(7,i)*scaleH(1)*conradH*2 vels(8,i)*scaleH(2)*conradH*2];
        % Make structure tag for error ellipose
        elld = struct('Site',i,'Fld',fld,'Pos',[vels(1,i) vels(2,i)]);
        if vels(7,i) ~=0 && vels(7,i)  % Only plot error ellipse if non-zero size
          hhe(i) = rectangle('Position',errpos, ...
                  'Curvature',[1,1],  ...   % Tag later tells us which field
                  'FaceColor',arrowstr.Errch, 'EdgeColor',[0 0 0], ...
                  'Tag','HERR','UserData',elld);
        end
        %
        % Make structure that contains what this is GPSH and site number an
        % fld
        vecd = struct('Site',i,'Fld',fld);
        hhp(i) = plot(lx,ly,'ButtonDownFcn',cb, ...
            'LineWidth',arrowstr.Widh,'Color',arrowstr.Colh,...
            'Tag','GPSH', 'UserData',vecd);
    end
end
% See if we are to display the height field.
if velinf.DisplayV
    for i = 1:num
        % Now generate the error bar.
        if vels(12,i) ~= 0
            [lx,ly] = HghErrorBar(vels(:,i), scaleV, arrowstr,velinf);
            hgte = struct('Site',i,'Fld',fld,'Pos',[vels(1,i) vels(2,i)]);
            hve(i) = plot(lx,ly,'Color',[0 0 0], ...
                'Tag','VERR','UserData',hgte);
        end
        % Now plot the values
        lx = [vels(1,i) vels(1,i)];
        if ~isempty(names)
            cb = sprintf('velgui(''HVector'',''%8s'',%3d,%1d)',names(i,:), i,fld);
        else
            cb = []; 
        end

        ly = [vels(2,i) vels(2,i)+vels(10,i)*sn(2)*av];
        % Make structure with point information
        hgtd = struct('Site',i,'Fld',fld);
        if vels(10,i) > 0 
            hvp(i) = plot(lx,ly,'ButtonDownFcn',cb, ...
                 'LineWidth',arrowstr.Widv,'Color',arrowstr.Colvu,...
                'Tag','GPSV', 'UserData',hgtd);
        else
             hvp(i) = plot(lx,ly,'ButtonDownFcn',cb, ...
                 'LineWidth',arrowstr.Widv,'Color',arrowstr.Colvd,...
                'Tag','GPSV', 'UserData',hgtd);
        end
        
    end
end
    
% See if we should display names
if velinf.DisplayN
    for i = 1:num
        if ~isempty(names)   % Only display name if available
            txtd = struct('Site',i,'Fld',fld);
            ht(i) = text(vels(1,i),vels(2,i),names(i,1:4), 'fontsize',9,...
                'Clipping','on','VerticalAlignment','top', 'Interpreter','none', ...
                'Tag','SITN','UserData',txtd);
        end
    end
end
%
% Save the handles so that when we load another data set these can be
% removed from the screen.
handles = struct('HVec',hhp, 'HErr',hhe, 'Harr',hha, ...
    'VVec',hvp, 'VErr',hve, 'Names', ht);

