function ProfGUIcb(option)
% ProfGUIcb(option): Call back routines for the Profile GUI
%

% Get the profile structure form the figure handle
hpf = gcf; profstr = get(hpf,'UserData');
fs = 10 ; % Set fontsize (default is 10)

% Run down the case statements
switch(option)
    
    case 'ID'
        % Use ginput to get currrent coordinates and see who it is
        % Get the handles of the points currently ID'd on the screen
        button = 3; nid = 0;
        profxy = profstr.Profxy;
        while button == 3
            [pt, button] = GetProfPut(profxy);
            % See if there are points returned
            if ~isempty(pt)
                % Compute position on screen
                for i = 1:length(pt)
                    j = pt(i);
                    pos = [0.01 0.20-nid*0.025 0.18 0.18];
                    idtext = sprintf(['Site: %s\n', ...
                        'Dist %7.2f km\nOffT %7.2f km\n', ...
                        'AP %6.2f+-%6.2f\nCT %6.2f+-%6.2f\n', ...
                        'Ht %6.2f+-%6.2f'], ...
                         profstr.ProfName(j,:), ...
                         profstr.Profxy(j,[1 8 2 3 4 5 6 7]));
                    hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[1 1-nid/10 0.78], ...
	                    'String',idtext, ...
                        'FontSize',fs, ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','IDtext');
                    nid = nid + 1;
                end
            end
        end            
        %
    case 'Fit'
        % Get the function that we are gping to fit
        hfn = findobj(gcf,'Tag','FCN1'); fcn1 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN2'); fcn2 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN3'); fcn3 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN4'); fcn4 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN5'); fcn5 = get(hfn,'String');
        
        % Get the data
        profxy = profstr.Profxy;
        
        % Loop pver each axis  ALONG TRACK
        ha = findobj(gcf,'Tag','ProfAx1'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,2),profxy(:,3), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        hl = findobj(ha,'Tag','FitL1'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        set(hl,'YData',LineT);
        
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfATData'); 
        set(hd,'XData',profxy(:,1),'YData',profxy(:,2),'Udata',profxy(:,3),'Ldata',profxy(:,3));
        drng = (max(profxy(:,2))-min(profxy(:,2))+0.5)/20;
        axis([xlim min(profxy(:,2))-drng max(profxy(:,2))+drng]);

        pos = [0.01 .33 0.18 0.16];
        nsites = size(profxy,1); 
        fittxt = sprintf('Along Track: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.7 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','FitTxt1');
                    
        % Save the results
        SolnAT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
        % Loop pver each axis  CROSS TRACK
        ha = findobj(gcf,'Tag','ProfAx2'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,4),profxy(:,5), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        hl = findobj(ha,'Tag','FitL2'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        set(hl,'YData',LineT);
        
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfCTData'); 
        set(hd,'XData',profxy(:,1),'YData',profxy(:,4),'Udata',profxy(:,5),'Ldata',profxy(:,5));
        drng = (max(profxy(:,4))-min(profxy(:,4))+0.5)/20;
        axis([xlim min(profxy(:,4))-drng max(profxy(:,4))+drng]);

        pos = [0.01 .17 0.18 0.16];
        fittxt = sprintf('Cross Track: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.6 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','FitTxt1');
        % Save the results
        SolnCT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
        % Loop pver each axis  HEIGHT
        ha = findobj(gcf,'Tag','ProfAx3'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,6),profxy(:,7), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        hl = findobj(ha,'Tag','FitL3'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        set(hl,'YData',LineT);
        
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfHTData'); 
        set(hd,'XData',profxy(:,1),'YData',profxy(:,6),'Udata',profxy(:,7),'Ldata',profxy(:,7));
        drng = (max(profxy(:,6))-min(profxy(:,6))+0.5)/20;
        axis([xlim min(profxy(:,6))-drng max(profxy(:,6))+drng]);

        pos = [0.01 .01 0.18 0.16];
        fittxt = sprintf('Height: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.5 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text','Enable','inactive', ...
	                    'Tag','FitTxt1');
        % Save the results
        SolnHT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
        % Save the functions used
        SolnFCN = struct('FCN1',fcn1,'FCN2',fcn2,'FCN3',fcn3,'FCN4',fcn4,'FCN5',fcn5);
        
        % Save all parts of the solution
        Soln = struct('SolnAT',SolnAT,'SolnCT',SolnCT,'SolnHT',SolnHT,'SolnFCN',SolnFCN);
        
        % Find the handle for the fit buttin and save results
        hfn = findobj(gcf,'Tag','ProfFit'); set(hfn,'UserData',Soln);
        
    case 'ProfRes'
        % Plot the residuals rather than the total profile.
        % Get the fitting function information: Here we re-fit to generate
        % the residuals
        hfn = findobj(gcf,'Tag','FCN1'); fcn1 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN2'); fcn2 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN3'); fcn3 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN4'); fcn4 = get(hfn,'String');
        hfn = findobj(gcf,'Tag','FCN5'); fcn5 = get(hfn,'String');
        
        % Get the data
        profxy = profstr.Profxy;
        
        % Loop pver each axis  ALONG TRACK
        ha = findobj(gcf,'Tag','ProfAx1'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,2),profxy(:,3), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        
        hl = findobj(ha,'Tag','FitL1'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        % Get line that was drawn and replace with zero since this is
        % residual
        LineZ = zeros(length(md),1);
        set(hl,'YData',LineZ);
        
        % Gnerate fit values at the times of fata
        od = Res;
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfATData'); 
        set(hd,'XData',profxy(:,1),'YData',od,'Udata',profxy(:,3),'Ldata',profxy(:,3));
        drng = (max(od)-min(od)+0.5)/20;
        axis([xlim min(od)-drng max(od)+drng]);

       
        pos = [0.01 .33 0.18 0.16];
        nsites = size(profxy,1); 
        fittxt = sprintf('Along Track: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        % str = sprintf('Function Fit: %2d Functions: WRMS %6.1f mm/yr, NRMS %6.2f; %d sites',length(FcnF),statf([1 2 3]));
        % ht = text('String',str,'Tag','TextL1', ...
        %    'VerticalAlignment','bottom','Units','normalized',...
        %    'Position',[0.02 1.10 0],'Background',[0.9 0.9 0.9]); 
       
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.7 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','FitTxt1');
        % Save the results
        SolnAT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
                    
        % Loop pver each axis  CROSS TRACK
        ha = findobj(gcf,'Tag','ProfAx2'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,4),profxy(:,5), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        
        % Get line that was drawn and replace with zero since this is
        % residual
        hl = findobj(ha,'Tag','FitL2'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);

        LineZ = zeros(length(md),1);
        set(hl,'YData',LineZ);
        
        % Gnerate fit values at the times of fata
        od = Res;
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfCTData'); 
        set(hd,'XData',profxy(:,1),'YData',od,'Udata',profxy(:,5),'Ldata',profxy(:,5));
        drng = (max(od)-min(od)+0.5)/20;
        axis([xlim min(od)-drng max(od)+drng]);

        
        
        pos = [0.01 .17 0.18 0.16];
        fittxt = sprintf('Cross Track: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.6 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','FitTxt1');
        % Save the results
        SolnCT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
        % Loop pver each axis  HEIGHT
        ha = findobj(gcf,'Tag','ProfAx3'); axes(ha);
        ax1 = [xlim ylim];
        % Now fit mean and trend to height rates
        [FcnF, CovF, Res, statf] = Wfit(profxy(:,1),profxy(:,6),profxy(:,7), ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        
        % Get line that was drawn and replace with zero since this is
        % residual
        hl = findobj(ha,'Tag','FitL3'); md = get(hl,'XData');
        [LineT, sig] = Wmod(md,FcnF, CovF, ...
            '1',fcn1,fcn2,fcn3,fcn4,fcn5);
        LineZ = zeros(length(md),1);
        set(hl,'YData',LineZ);
        
        % Gnerate fit values at the times of fata
        od = Res;
        % Reset the data plot incase residuals have been plotted
        hd = findobj(ha,'Tag','ProfHTData'); 
        set(hd,'XData',profxy(:,1),'YData',od,'Udata',profxy(:,7),'Ldata',profxy(:,7));
        drng = (max(od)-min(od)+0.5)/20;
        axis([xlim min(od)-drng max(od)+drng]);

        
        pos = [0.01 .01 0.18 0.16];
        fittxt = sprintf('Height: %d Sites\n',nsites);
        fittxt = [fittxt sprintf('WRMS %4.2f NRMS %4.2f\n', statf([1 2]))];
        for i = 1:length(FcnF)
            fittxt = [fittxt sprintf('FCN%1d %6.2f+-%6.2f\n', ...
                    i-1,FcnF(i),sqrt(CovF(i,i)))];
        end
        hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[0.5 1 0.78], ...
	                    'String',fittxt, ...
                        'FontSize',fs, 'FontUnits','points', ...
                        'FontName','Monospaced', ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text','Enable','inactive', ...
	                    'Tag','FitTxt1');
        % Save the results
        SolnHT = struct('FcnF',FcnF,'CovF',CovF,'Res',Res,'StatF',statf, ...
            'ModelD',md,'ModelF',LineT,'ModelS',sig);
        
        % Save the functions used
        SolnFCN = struct('FCN1',fcn1,'FCN2',fcn2,'FCN3',fcn3,'FCN4',fcn4,'FCN5',fcn5);
        
        % Save all parts of the solution
        Soln = struct('SolnAT',SolnAT,'SolnCT',SolnCT,'SolnHT',SolnHT,'SolnFCN',SolnFCN);
        
        % Find the handle for the fit buttin and save results
        hfn = findobj(gcf,'Tag','ProfFit'); set(hfn,'UserData',Soln);

        
        
    case 'Delete'
        % Use ginput to get currrent coordinates and see who it is
        % Get the handles of the points currently ID'd on the screen
        button = 3; nid = 0;
        profxy = profstr.Profxy;
        allpt = [];
        
        while button == 3
            [pt, button] = GetProfPut(profxy);
            % See if there are points returned
            if ~isempty(pt)
                % Find the axes and plot an X over the point
                ha = findobj(gcf,'Tag','ProfAx1'); axes(ha);
                ch = get(ha,'Children'); plotd = get(ch(length(ch)),'Ydata');
                plot(profxy(pt(1),1),plotd(pt(1)),'kx','MarkerSize',12);
                ha = findobj(gcf,'Tag','ProfAx2'); axes(ha);
                ch = get(ha,'Children'); plotd = get(ch(length(ch)),'Ydata');
                plot(profxy(pt(1),1),plotd(pt(1)),'kx','MarkerSize',12);
                ha = findobj(gcf,'Tag','ProfAx3');axes(ha);
                ch = get(ha,'Children'); plotd = get(ch(length(ch)),'Ydata');
                plot(profxy(pt(1),1),plotd(pt(1)),'kx','MarkerSize',12);
                pos = [0.01 0.01 0.35 0.025];
                deltext = sprintf('Deleting site: %s, %d sites remaining', ...
                         profstr.ProfName(pt(1),:), ...
                         length(profstr.Profxy(:,1))-1);
                hk = uicontrol('Parent',gcf, ...
	                    'Units','normalized', ...
	                    'Position',pos, ...
                        'BackgroundColor',[1 .1 .1], ...
	                    'String',deltext, ...
                        'FontSize',fs, ...
                        'HorizontalAlignment','left', ...
                        'ButtonDownFcn','delete(gcbo)', ...
	                    'Style','text', 'Enable','inactive',...
	                    'Tag','Deltext');
                
                % Just remove the first one from the selected list
                allpt = [allpt pt];
            end
        end
        nd = length(profxy(:,1));
        eds = logical(ones(nd,1));
        eds(allpt) = 0;
        % Save results will all edits
        profstr.Profxy = profstr.Profxy(eds,:);
        profstr.ProfName = profstr.ProfName(eds,:);
        set(gcf,'UserData',profstr);
        
    case 'Save'
        
        % Get the file name from the save box
        he = findobj(gcf, 'Tag', 'ProfSaveName');
        editfile = get(he,'String');
        [fid, message] = fopen(editfile,'a');
        if fid == -1
            disp(['Error opening ' editfile ' : ' message])
        else        
        
            % Find the solution to the function fits
            hfn = findobj(gcf,'Tag','ProfFit'); Soln = get(hfn,'UserData');
            % Break the struture down for each compontent
            SolnAT = Soln.SolnAT; SolnCT = Soln.SolnCT; SolnHT = Soln.SolnHT; 
            profstr = get(gcf,'UserData');
            
            % Write out the information about the profile position
            fprintf(fid,'* PROFILE SAVE\n');
            fprintf(fid,'* Box enclosing sites (center line and then box)\n*     Longitude  Latitude (deg)\n');
            fprintf(fid,'BOX  %8.4f  %8.4f\n',profstr.ProfLL');
            
            % Report the functions used in the fitting of the profile
            fprintf(fid,'* Functions used in fitting the profile\n');
            fprintf(fid,'* FCN0  Offset (mm/yr)\n');
            SolnFCN = Soln.SolnFCN;
            if ~isempty(SolnFCN.FCN1); fprintf(fid,'* FCN1 %s\n',SolnFCN.FCN1); end
            if ~isempty(SolnFCN.FCN2); fprintf(fid,'* FCN2 %s\n',SolnFCN.FCN2); end
            if ~isempty(SolnFCN.FCN3); fprintf(fid,'* FCN3 %s\n',SolnFCN.FCN3); end
            if ~isempty(SolnFCN.FCN4); fprintf(fid,'* FCN4 %s\n',SolnFCN.FCN4); end
            if ~isempty(SolnFCN.FCN5); fprintf(fid,'* FCN5 %s\n',SolnFCN.FCN5); end
                
            % For along track, cross track and height write out the
            % estimates and values
            % Soln estimates: Along Track
            fprintf(fid,'* Solution estimates at azimuth %6.2f deg MAT\n',profstr.ProfAz*180/pi);
            fprintf(fid,'* Statistics: For %d sites, WRMS %6.2f mm/yr, NRMS %6.3f\n', ...
                SolnAT.StatF([3 1 2]));
            fprintf(fid,'* FCN0  %6.2f +- %6.2f mm/yr MAT\n', SolnAT.FcnF(1),sqrt(SolnAT.CovF(1,1)));
            for i = 2:length(SolnAT.FcnF);
                fprintf(fid,'* FCN%1d  %6.2f +- %6.2f mm/yr MAT\n', ...
                    i-1,SolnAT.FcnF(i), sqrt(SolnAT.CovF(i,i)));
            end
            fprintf(fid,'* Velocities projected to %6.2f deg\n',profstr.ProfAz*180/pi);
            fprintf(fid,'*    Dst km   Along     +-     Resid     +-    OffProf Name\n');

            for i = 1: length(SolnAT.Res)
                fprintf(fid,'PAT %8.2f %7.2f  %7.2f %7.2f  %7.2f %8.2f %s\n',...
                    profstr.Profxy(i,[1 2 3]), SolnAT.Res(i), profstr.Profxy(i,[3 8]), profstr.ProfName(i,:)) ;
            end
            % Write out the Model
            fprintf(fid,'* Model Values\n*    Dst km   Along     +- (mm/yr)\n');
            for i = 1:length(SolnAT.ModelD)
                fprintf(fid,'MAT %8.2f %7.2f  %7.2f\n', ...
                 SolnAT.ModelD(i), SolnAT.ModelF(i), SolnAT.ModelS(i));
            end
            
            %%%% Cross track values
            caz = profstr.ProfAz-pi/2; 
            if caz < -pi/2, caz = caz+2*pi; end
            fprintf(fid,'* Solution estimates at azimuth %6.2f deg MCT\n',caz*180/pi);
            fprintf(fid,'* Statistics: For %d sites, WRMS %6.2f mm/yr, NRMS %6.3f\n', ...
                SolnCT.StatF([3 1 2]));

            fprintf(fid,'* FCN0  %6.2f +- %6.2f mm/yr MCT\n', SolnCT.FcnF(1),sqrt(SolnCT.CovF(1,1)));
            for i = 2:length(SolnCT.FcnF);
                fprintf(fid,'* FCN%1d  %6.2f +- %6.2f mm/yr MCT\n', ...
                    i-1,SolnCT.FcnF(i), sqrt(SolnCT.CovF(i,i)));
            end
            fprintf(fid,'* Velocities projected to %6.2f deg\n',profstr.ProfAz*180/pi);
            fprintf(fid,'*    Dst km   Along     +-     Resid     +-    OffProf Name\n');

            for i = 1: length(SolnCT.Res)
                fprintf(fid,'PCT %8.2f %7.2f  %7.2f %7.2f  %7.2f %8.2f %s\n',...
                    profstr.Profxy(i,[1 4 5]), SolnCT.Res(i), profstr.Profxy(i,[5 8]), profstr.ProfName(i,:)) ;
            end
            % Write out the Model
            fprintf(fid,'* Model Values\n*    Dst km   Along     +- (mm/yr)\n');
            for i = 1:length(SolnCT.ModelD)
                fprintf(fid,'MCT %8.2f %7.2f  %7.2f\n', ...
                 SolnCT.ModelD(i), SolnCT.ModelF(i), SolnCT.ModelS(i));
            end
            
            % Now do the height computr
            fprintf(fid,'* Solution estimates for Height Rates MHT\n');
            fprintf(fid,'* Statistics: For %d sites, WRMS %6.2f mm/yr, NRMS %6.3f\n', ...
                SolnHT.StatF([3 1 2]));
            fprintf(fid,'* FCN0  %6.2f +- %6.2f mm/yr  MHT\n', SolnHT.FcnF(1),sqrt(SolnHT.CovF(1,1)));
            for i = 2:length(SolnHT.FcnF);
                fprintf(fid,'* FCN%1d  %6.2f +- %6.2f mm/yr MHT\n', ...
                    i-1,SolnHT.FcnF(i), sqrt(SolnHT.CovF(i,i)));
            end
            fprintf(fid,'* Velocities projected to %6.2f deg\n',profstr.ProfAz*180/pi);
            fprintf(fid,'*    Dst km   Along     +-     Resid     +-    OffProf Name\n');

            for i = 1: length(SolnHT.Res)
                fprintf(fid,'PHT %8.2f %7.2f  %7.2f %7.2f  %7.2f %8.2f %s\n',...
                    profstr.Profxy(i,[1 6 7]), SolnHT.Res(i), profstr.Profxy(i,[5 8]), profstr.ProfName(i,:)) ;
            end
            % Write out the Model
            fprintf(fid,'* Model Values\n*    Dst km   Along     +- (mm/yr)');
            for i = 1:length(SolnHT.ModelD)
                fprintf(fid,'MHT %8.2f %7.2f  %7.2f\n', ...
                 SolnHT.ModelD(i), SolnHT.ModelF(i), SolnHT.ModelS(i));
            end
               
            fclose(fid);
        
        end
        
        
        
end
