function saven = RemoveDups(save1,closesep)
% saven = RemoveDups(save1) Removes the duplicates based on separation

% Extract the velocity field and information from the save1 structure
vel1 = save1.Vel; name1 = save1.Name; vel1inf = save1.VellInf;

% Report what is happening
fprintf(1,'Removing duplicate sites separated by less than %6.1f km\n',closesep);

% Set up logical array which will be used to select sites
nd = length(vel1(1,:));
eds = logical(ones(nd,1));
dtr = pi/180;
ccs = cos(closesep/6371.0);

nrm = [0 0]; 

for i = 1:nd-1
    for j = i+1:nd
        % Check to see if velocities are equal
        if vel1(3,i) == vel1(3,j) & vel1(4,i) == vel1(4,j) & ...
            vel1(10,i) == vel1(10,j) & eds(j) == 1
        
            % Velocities match see if within separation
            cosg =  sin(vel1(2,i)*dtr)*sin(vel1(2,j)*dtr) + ...
                cos(vel1(2,i)*dtr)*cos(vel1(2,j)*dtr)*cos((vel1(1,i)-vel1(1,j))*dtr);
            if cosg >= ccs
                % sites are closer so report and eliminate j
                dist = acos(cosg)*6371.0;
                % Only report if non-zero separation
                if dist > 1.e-4
                    fprintf(1,'Removing %s, equal velocity and %8.5f km from %s\n', ...
                           name1(j,:),dist,name1(i,:));
                    nrm(2) = nrm(2)+1;
                else
                    nrm(1) = nrm(1)+1;
                end
                eds(j) = 0;
            end
        end
    end
end
%
fprintf('Removed %d sites with 0 km separation and %d sites with >0 km separation\n',nrm);
% Create the field and save in structure
veln = vel1(:,eds); namn = name1(eds,:);
saven = struct('Vel',veln,'Name',namn,'VellInf',vel1inf);

            

