function VecActions(num,fld)
% VecActions: Functions for actions that can be done with vectors.
% num is the site number and fld is the field number (VelName1, VelName2 or
% EnsName).
%
% Get the handles as to how we got here
[hcb hf] = gcbo;  % Handle to callback object and associated figure
ha = gca;         % Handle to axes for plot
%
opt = get(hcb,'Value');
% Based on the field number passed, get the data
if fld == 1, FieldName = 'VelName1';
elseif fld == 2, FieldName = 'VelName2';
else FieldName = 'EnsName'; end

% Get the handle to the data and extract
hn = findobj(hf,'Tag',FieldName);
veldat = get(hn,'UserData');

% Get the offsets that have been applied to the plot
% ho = findobj(hf,'Tag','Offvalue');
% offs = str2num(get(ho,'String'));
[offs, aligns] = GetOffset(hf); 
veld = veldat.Vel(:,num);
if offs(7) > 0 
    veld = AppOffAlign(offs, aligns,fld, veld);
end

%fprintf(1,'Action passed to VecActions %d %d with opt %d\n',num,fld,opt);

% See what we want to do.  opt == 1 is just the site name and does nothing
if opt == 2
    % Label on Figure
    vtext = sprintf(['Site %8s Field %d\n' ...
            'Long %6.3f Lat %6.3f\n' ...
            'Comp       V        SigV   Orig\n' ...
            'North   %6.2f +- %6.2f %6.2f\n' ...
            'East    %6.2f +- %6.2f %6.2f\n',...
            'Height  %6.2f +- %6.2f %6.2f'], ...
            veldat.Name(num,:), fld, veld([1 2]), ...
            veld([4 8 6 3 7 5 10 12 11 ]));
     
    vpos = [veld(1) veld(2)];
    hx = text(vpos(1),vpos(2),vtext, 'VerticalAlignment','bottom', ...
             'ButtonDownFcn','delete(gcbo)','Interpreter','none', ...
             'FontName','Monospaced', ...
             'BackgroundColor',[1 1 0.85], ...
             'EdgeColor',[0 0 0]);
%            'BackgroundColor',[1 1 0], ...  % Version 6.5 Add line
    % Get the position of the text ares
%    tz = get(hx,'Extent');
    % Make up patch to cover
%    xp = [tz(1) tz(1)+tz(3)+0.01 tz(1)+tz(3)+0.01 tz(1) tz(1)];
%    yp = [tz(2) tz(2) tz(2)+tz(4) tz(2)+tz(4) tz(2)];
%    hp = patch(xp,yp,[1 1 .85],'ButtonDownFcn','delete(gcbo)');
    % Save the gcbo and the patch handle in the UserData; then the delete
    % call back is executing the values in the handle
    %hd = gcbo ;  % hd = [gcbo;hp];
    % set(gcbo,'UserData',hd);
    % bdf = 'DeleteText';

    % ht = text(vpos(1),vpos(2),vtext, 'VerticalAlignment','bottom', ...
    %         'ButtonDownFcn',bdf,'Interpreter','none', ...
    %         'FontName','Monospaced');
    %         hd = [ht;hd];
    % set(ht,'UserData',hd);

    % delete(hx);
         

elseif opt == 3
    % Label on a new figure
    vtext = sprintf(['Site %8s Field %d\n' ...
            'Long %6.3f Lat %6.3f\n' ...
            'Comp       V        SigV   Orig\n' ...
            'North   %6.2f +- %6.2f %6.2f\n' ...
            'East    %6.2f +- %6.2f %6.2f\n',...
            'Height  %6.2f +- %6.2f %6.2f'], ...
            veldat.Name(num,:), fld, veld([1 2]), ...
            veld([4 8 6 3 7 5 10 12 11 ]));
    figsize = get(gcf,'position');
    scnsize = get(0,'ScreenSize');
    %pos = fix([scnsize(3)-260 scnsize(4)-125 255 120]);
    % Align with top of figure.
    pos = fix([scnsize(3)-260 figsize(2)+figsize(4)-125 255 120]);
 
    hr = figure('Units','pixels', ...
           'MenuBar','none', ...
           'Position',pos, ...
            'Tag','Result1');
    fs = 10 ; % if strcmp(getenv('OSTYPE'),'linux') , fs = 9 ; end
          
    hk = uicontrol('Parent',hr, ...
	       'Units','pixels', ...
	       'Position',[2 0 255 120], ...
           'BackgroundColor',[1 1 0.78], ...
	       'String',vtext, ...
           'FontSize',fs, ...
           'FontName','Monospaced', ...
           'HorizontalAlignment','left', ...
	       'Style','text', 'Enable','inactive', ...
	       'Tag','OutResult1');
                        
    
elseif opt == 4
    % Launch tsview so that we can look at time series
    % See if the directory is set
    hd = findobj(gcf,'Tag','mbDIR');
    mbdir = get(hd,'String');
    if isempty(mbdir)
        tsview(veldat.Name(num,:));
    else
        fprintf('Getting time series for %s in directory %s\n',veldat.Name(num,:),mbdir);
        tsview(veldat.Name(num,:),mbdir);
    end
    
elseif opt == 5
    % This is the delete feature.
    % Get the data from the appropriate field and delete
    hn = findobj(hf,'Tag',FieldName);
    totnum = length(veldat.Vel(1,:));
    if num == 1
        veldat.Vel = veldat.Vel(:,[2:totnum]); 
        veldat.Name = veldat.Name([2:totnum],:);
    elseif num == totnum
        veldat.Vel = veldat.Vel(:,[1:num-1]);
        veldat.Name = veldat.Name([1:num-1],:);
    else 
        veldat.Vel = veldat.Vel(:,[1:num-1 num+1:totnum]);
        veldat.Name = veldat.Name([1:num-1 num+1:totnum],:);
    end
    %
    % Now find the objects on the screen and remove these.  There are 5
    % things that may need to be remove: Horizontal Vector, ellipse,
    % vertical estimate, error bar and site name (for the moment leave the
    % name on screen)
    % Get the children of the current axes
    ho = get(ha,'Children');
    for i = 1:length(ho)
        % Get the Tag and see if matches
        tag = get(ho(i),'Tag');
        if strcmp(tag,'GPSH') % Horizontal vector
            % Does site and field match
            vecd = get(ho(i),'UserData');
            if vecd.Site == num & vecd.Fld == fld, delete(ho(i)); 
            elseif vecd.Site > num & vecd.Fld == fld, 
                % If this site after the current one, update its number in
                % the handle and in the callback.
                vecd.Site = vecd.Site - 1; 
                cb = get(ho(i),'ButtonDownFcn');
                if ~isempty(cb)
                    cb = sprintf('velgui(''HVector'',''%8s'',%4d,%1d)', ...
                        veldat.Name(vecd.Site,:), vecd.Site,fld);
                else cb = []; end
                set(ho(i),'UserData',vecd,'ButtonDownFcn',cb);
            end 
        elseif strcmp(tag,'GPSV') % Vertical vector
            % Does site and field match
            vecd = get(ho(i),'UserData');
            if vecd.Site == num & vecd.Fld == fld, delete(ho(i)); 
            elseif vecd.Site > num & vecd.Fld == fld, 
                % If this site after the current one, update its number in
                % the handle and in the callback.
                vecd.Site = vecd.Site - 1; 
                cb = get(ho(i),'ButtonDownFcn');
                if ~isempty(cb)
                    cb = sprintf('velgui(''HVector'',''%8s'',%4d,%1d)', ...
                        veldat.Name(vecd.Site,:), vecd.Site,fld);
                else cb = []; end
                set(ho(i),'UserData',vecd,'ButtonDownFcn',cb);
            end 
        elseif strcmp(tag,'HERR') % Horizontal error ellipse
            % Does site and field match
            vecd = get(ho(i),'UserData');
            if vecd.Site == num & vecd.Fld == fld, delete(ho(i)); 
            elseif vecd.Site > num & vecd.Fld == fld, 
                vecd.Site = vecd.Site - 1; set(ho(i),'UserData',vecd);
            end 
       elseif strcmp(tag,'VERR') % Vertical Error bar
            % Does site and field match
            vecd = get(ho(i),'UserData');
            if vecd.Site == num & vecd.Fld == fld, delete(ho(i)); 
            elseif vecd.Site > num & vecd.Fld == fld, 
                vecd.Site = vecd.Site - 1; set(ho(i),'UserData',vecd);
            end 
        elseif strcmp(tag,'SITN') % Site Name
            % Does site and field match
            vecd = get(ho(i),'UserData');
            if vecd.Site == num & vecd.Fld == fld, delete(ho(i)); 
            elseif vecd.Site > num & vecd.Fld == fld, 
                vecd.Site = vecd.Site - 1; set(ho(i),'UserData',vecd);
            end 
        end
    end
    % Save the data back into the handle. (Drawnow is needed for mutiple
    % deletes to work).
    set(hn,'UserData',veldat); drawnow;

    
end
    
         

% Delete the menu
delete(hcb);
