function stats = WAlign(vel1,name1,vel2,name2);
% stats = WAlign(vel1,name1,vel2,name2): Function to compute weight
% mean offset between two fields.
% stats returns #site WMean_N Sig M WRMS_N NRMS_N WMean_E SigE WRMS_E
% NRMS_E Wmean_U SigU WRMS_U NRMS_U
%
% Find the wmean for each component
% stats = zeros(1,13);

% Get the current value of the close separation sites
closesep = str2double(get(findobj(gcf,'Tag','CloseSep'),'String'));
% pause before continuing
pause(2)

% Generate the difference bwteen the two fields.
% Set up logical array which will be used to select sites
dtr = pi/180;
ccs = cos(closesep/6371.0);
n1 = length(vel1(1,:)); n2 = length(vel2(1,:));
fprintf(1,['Difference between %d primary and %d secondary sites in current view\n' ...
        'with same name or separated by less than %6.1f km\n'], ...
    n1,n2,closesep);

num = 0;
fprintf(1,'  Site2    Site1  Sep (km) East Diff  +-  North Diff +-  Up Diff   +-\n');
dvel = []; namd = [];
for i = 1:n1
    % First check to see if we match on name, if this fails check distance
    j = 0;
    for k = 1:n2
        if strcmp(name2(k,:),name1(i,:)), j = k; cosg = 1.0; end
    end
    if j == 0 && closesep > 0   % Check for distance (if separation is zero 
                               % use only same named sites      
        for k = 1:n2
       
            % Velocities match see if within separation
            cosg =  sin(vel1(2,i)*dtr)*sin(vel2(2,k)*dtr) + ...
                cos(vel1(2,i)*dtr)*cos(vel2(2,k)*dtr)*cos((vel1(1,i)-vel2(1,k))*dtr);
            if cosg >= ccs, j =k; end
        end
    end
    if j ~= 0            
        % sites are close enough so report on difference
        dEv = vel2(3,j)-vel1(3,i); sE = sqrt(vel2(7,j)^2+vel1(7,i)^2);
        dNv = vel2(4,j)-vel1(4,i); sN = sqrt(vel2(8,j)^2+vel1(8,i)^2);
        dUv = vel2(10,j)-vel1(10,i); sU = sqrt(vel2(12,j)^2+vel1(12,i)^2);
        num = num + 1;

        dist = acos(cosg)*6371.d0;
        fprintf('%s %s %6.2f    %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n', ...
                name2(j,:), name1(i,:), dist, dEv, sE, dNv, sN, dUv, sU)
        % Save dvel in transpose form and then transpsoe when we are
        % done.
        dvel = [dvel ; vel2([1 2],j)' dEv dNv dEv dNv sE sN 0.00 dUv dUv sU];
        namd = [namd ; name2(j,:) '-' name1(i,:)];
    end
end

% Pause before continuing
pause(2)
dvel = dvel';
% Finish up the statistics
if num == 0 
    fprintf('No sites found\n'); return
end
    
% 
% for i = 1:3
%     if i == 1, Vals = dvel(4,:); Sig = dvel(8,:);       % North
%     elseif i == 2, Vals = dvel(3,:); Sig = dvel(7,:);   % East
%     elseif i == 3, Vals = dvel(10,:); Sig = dvel(12,:); % Up
%     end
%     %
%     % Form the weight vector
%     num = length(Vals);
%     w = 1./Sig.^2;
%     Wmean = w*Vals'/sum(w);
%     r = Vals - Wmean;
%     if num > 1, nrms = sqrt(sum(r.^2.*w)/(num-1)); else chi = 1; end
%     wrms = nrms*sqrt(num/sum(w));
%     stats(1) = num; stats(2+4*(i-1)) = Wmean; stats(3+4*(i-1)) = wrms/sqrt(num);
%     stats(4+4*(i-1)) = wrms; stats(5+4*(i-1)) = nrms;
% end

[param, sigp, stats, res, sigd] = WEuler(dvel,namd);
hov = findobj(gcf,'Tag','Alignvalue');
encodeparam(hov, param);
np = length(param);

ht = findobj(gcf,'Tag','EstTran'); hr = findobj(gcf,'Tag','EstRot');
et = get(ht,'Value'); er = get(hr,'Value');
vtext = sprintf('Alignment Results from %d sites and %d param (click to remove)\n',stats(1),np);
vtext = [vtext  sprintf('Param        Est       +-   C  WRMS (mm/yr) NRMS\n')];

comps = ['dN mm/yr'; 'dE mm/yr'; 'dU mm/yr'; ...
         'dX mm/yr'; 'dX mm/yr'; 'dZ mm/yr'; ...
         'Wx rd/by'; 'Wy rd/by'; 'Wz rd/by'] ;
rmslb = 'NEU' ;
off = 0 ;
if et == 1 , off=3 ; end
if et == 0 && er == 1 , off = 6; end
for k = 1:3
    vtext = [ vtext, sprintf('%s %8.2f %8.2f  %c %8.2f  %8.2f\n', ...
        comps(off+k,:),param(k),sigp(k),rmslb(k),stats(2*(k-1)+[2 3]))];
end
for k = 4:np
    vtext = [ vtext, sprintf('%s %8.2f %8.2f  \n', comps(3+k,:),param(k),sigp(k))];
end    

vtext = [ vtext, sprintf('Sites               NRes    +-    ERes    +-     URes    +-\n')];
for i = 1:length(res(1,:))
    vtext = [vtext, sprintf('%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n', ...
            namd(i,:), [res(:,i)' ; sigd(:,i)'])];
end

% % Now output a new figure the results on it.
% vtext = sprintf(['Alignment Results from %d sites (right-click to remove)\n', ...
%         'Comp         Wmean (mm)     WRMS  NRMS\n', ...
%         'North   %6.2f +- %6.2f  %6.2f %6.3f\n', ...
%         'East    %6.2f +- %6.2f  %6.2f %6.3f\n', ...
%         'Height  %6.2f +- %6.2f  %6.2f %6.3f\n', ....
%         'Sites               NRes +-       ERes +-        URes +-\n'], stats);
% for i = 1:num
%     vtext = [vtext, sprintf('%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n', ...
%             namd(i,:), dvel(4,i)-stats(2), dvel(8,i), ...
%             dvel(3,i)-stats(6), dvel(7,i), ...
%             dvel(10,i)-stats(10), dvel(12,i))];
% end
% 
% Get size of current axes
szfg = get(gcf,'Position');
pos = [szfg(3)-390 szfg(4)-(3+stats(1)+np)*13-3 390 (3+stats(1)+np)*13+3];
fs = 9 ; % if strcmp(getenv('OSTYPE'),'linux') , fs = 8 ; end
              
uicontrol('Parent',gcf, ...
	      'Units','pixels', ...
	      'Position',pos, ...
          'BackgroundColor',[1 1 0.78], ...
          'String',vtext, ...
          'FontSize',fs, ...
          'FontName','Monospaced', ...
          'HorizontalAlignment','left', ...
          'ButtonDownFcn','delete(gcbo)', ...
          'Style','text', 'Enable','inactive', ...
	      'Tag','OutResult2');
       
% Also output the results to the screen
fprintf(1,'--------------------------------------------------\n');
fprintf(1,'%s\n',vtext);
