function xyz = geod_to_xyz( clh )
% Convert co-lat, long, ht (clh) to XYZ
%       eccsq   = 2.d0*earth_flat - earth_flat**2
%  
%       rad_curve = earth_rad /
%      .            sqrt(1.d0 - eccsq*cos(geod_pos(1))**2 )
% 
%       site_pos(1) = (rad_curve+geod_pos(3))*sin(geod_pos(1)) *
%      .               cos(geod_pos(2))
%       site_pos(2) = (rad_curve+geod_pos(3))*sin(geod_pos(1)) *
%      .               sin(geod_pos(2))
%       site_pos(3) = ((1.d0-eccsq)*rad_curve+geod_pos(3))*
%      .               cos(geod_pos(1))
% 
% earth_flat = 1/298.257222101; 
earth_rad  =  6378137.0;       % WGS84/CRC80.
eccsq = 0.006694380023 ;       % 2*earth_flat - earth_flat^2; 
rad_curve = earth_rad/(1.0-eccsq*cos(clh(1))^2 )^0.5;
% Get Cartessian coordinates
xyz = [ (rad_curve+clh(3))*sin(clh(1))*cos(clh(2)) ; ...
        (rad_curve+clh(3))*sin(clh(1))*sin(clh(2)) ; ...       
        ((1.0-eccsq)*rad_curve+clh(3))*cos(clh(1)) ] ;
    
end    
