function Velinf = getVelinf(hf, name)
% getVelinf: Returns a structure with the information about one of the
% velocity field data sets: VelName1, VelName2 or ENsumFile.

% First get the file name
hfn = findobj(hf,'Tag',name);
velfilename = get(hfn,'String');

% Now get the information from the Load Options box
hfl = findobj(hf,'Tag','SigHLim');
sighlim = sscanf(get(hfl,'String'),'%f');
hfl = findobj(hf,'Tag','SigVLim');
sigvlim = sscanf(get(hfl,'String'),'%f');

% Get the scaling on the error bars
hfl = findobj(hf,'Tag','SigHScl');
sighscl = sscanf(get(hfl,'String'),'%f');
hfl = findobj(hf,'Tag','SigVScl');
sigvscl = sscanf(get(hfl,'String'),'%f');

% Get the error ellipse and error bar confidence intervals
hfl = findobj(hf,'Tag','ConfidH');
confidh = sscanf(get(hfl,'String'),'%f');
hfl = findobj(hf,'Tag','ConfidV');
confidv = sscanf(get(hfl,'String'),'%f');

% Get the arror lengths (approximately (mm on screen)/(mm real)
hfl = findobj(hf,'Tag','ArrowH');
arrowh = sscanf(get(hfl,'String'),'%f');
hfl = findobj(hf,'Tag','ArrowV');
arrowv = sscanf(get(hfl,'String'),'%f');

% Get arrow head size
%hfl = findobj(hf,'Tag','AHeadSize');
hfl = findobj(hf,'Tag','ArhHLimit');
aheadsize = get(hfl,'Value');

% Get the display option (on or off for horizontal and vertical)
hfl = findobj(hf,'Tag','DisplayH');
displayh = get(hfl,'Value');
hfl = findobj(hf,'Tag','DisplayV');
displayv = get(hfl,'Value');
hfl = findobj(hf,'Tag','DisplayN');
displayn = get(hfl,'Value');


% Set the structure with the information above this plot
Velinf = struct('Field',name, ...
    'FileName',velfilename, ...
    'SigHLim',sighlim,'SigVLim',sigvlim, ...
    'SigHScl',sighscl,'SigVScl',sigvscl, ... 
    'ConfidH',confidh,'ConfidV',confidv, ...
    'ArrowH', arrowh, 'ArrowV', arrowv, ...
    'AHeadSize', aheadsize, ...
    'DisplayH',displayh, 'DisplayV',displayv,'DisplayN',displayn ); 
