function fig = velview( InVelFile, InTSdir, fontsize) 
% VELVIEW: Main setup of GUI for displaying velocity plots
if nargin == 0
%
%  Print a small help description
   velver = 2.02;
   fprintf('+++++++++++++++++++++++++++\n');
   fprintf('+ VELVIEW    Version %4.2f +\n',velver);
   fprintf('+++++++++++++++++++++++++++\n');
   fprintf('Program to plot velocity fields and display time series of GPS positions\n');
   fprintf('Velocity fields and timeseries can be in original globk formats or PBO velocity and Position\n\n');
   fprintf('Version 2.00: PBO .vel and .pos formats introduced\n');
   fprintf('Version 2.01: Changed vertical velocity plotting\n');
   fprintf('Version 2.02: Allowed velocity field name to be passed and timeseries directory\n');
   fprintf('              Added search feature (sites displayed in red\n');
   fprintf('              Add translation/rotation option for alignment\n\n');
   fprintf('Call as: velview(%c<VelFile>%c,%c<Times series dir>%s,<fontsize>)\n',repmat(char(39),4,1));
   fprintf('Run as : velview VelFile> <Times series dir> <fontsize>\n');
   fprintf('Arguments are optional\n\n');
   fontsize = 10;
   InVelFile = [];
   InTSdir = [];
else
    if nargin == 3 
        if ~isnumeric(fontsize)
            fontsize = str2double(fontsize);
        end        
    elseif nargin == 2
        fontsize = 10 ; % Default font size
    elseif nargin == 1
        InTSdir = [];  
        fontsize = 10 ; % Default font size
    end        
end

% Reset the default line width in user has overwritten
set(0,'DefaultLineLineWidth',0.5);
%set(0,'ScreenPixelsPerInch',72);
set(0,'DefaultAxesBox','on');
set(0,'DefaultAxesTickDir','in');
set(0,'DefaultUicontrolFontSize',10)
set(0,'DefaultAxesFontSize',fontsize)
set(0,'DefaultTextFontSize',fontsize)

% Set root units to pixels and get screen size
set(0,'Units','pixels') ;
scnsize = get(0,'ScreenSize');

% Set an effective Max screen Size
if scnsize(3) > 1500 , scnsize(3) = 1500; end
if scnsize(4) > 1000 , scnsize(4) = 1000; end
 
% Compute the Figure size we want
figsize = [(scnsize(3)-scnsize(1))*0.80 (scnsize(4)-scnsize(2))*0.80];

% Generate the basic figure and then call the setup routine (which is also
% used for the resize function)

pos = [figsize(1)*0.1 figsize(2)*0.1 figsize(1) figsize(2) ];
h0 = figure('Units','pixels', ...
	'Color',[0.8 0.8 0.8], ...
	'Position',pos, ...
    'MenuBar','figure', ...
    'PaperPositionMode','auto', ...
	'Tag','FigVel');

VelFigSet('Load',InVelFile, InTSdir);    % Resize version is 'Resz'

%velgui('ClearAll');
%if 1 == 2 
%    VecActions(1,1);
%end

% Set this after initial figure call because ResizeFcn is called in figure
% before the initial load
set(h0,'ResizeFcn','VelFigSet(''Resz'')');

% fig = 0 ;
if nargout > 0, fig = h0; end
